#ifndef UU_COMPARE_H
#define UU_COMPARE_H

#include "uulib/UUID.h"

IV uu_cmp_binary(const uu_t uu1, const uu_t uu2);
IV uu_cmp_struct1(const struct uu *us1, const struct uu *us2);
IV uu_cmp_struct4(const struct uu4 *us1, const struct uu4 *us2);
IV uu_cmp_struct6(const struct uu6 *us1, const struct uu6 *us2);
IV uu_cmp_struct7(const struct uu7 *us1, const struct uu7 *us2);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
